@@ -44,13 +44,13 @@
 #include <gtk/gtktreeview.h>
 #include <libgnome/gnome-i18n.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
+#include <libgnomevfs/gnome-vfs-volume-monitor.h>
 #include <libnautilus-private/nautilus-file-attributes.h>
 #include <libnautilus-private/nautilus-file-operations.h>
 #include <libnautilus-private/nautilus-global-preferences.h>
 #include <libnautilus-private/nautilus-program-choosing.h>
 #include <libnautilus-private/nautilus-tree-view-drag-dest.h>
 #include <libnautilus-private/nautilus-icon-factory.h>
-#include <libnautilus-private/nautilus-volume-monitor.h>
 
 struct NautilusTreeViewDetails {
 	GtkWidget *scrolled_window;
@@ -64,6 +64,8 @@ struct NautilusTreeViewDetails {
 
 	char *selection_location;
 	gboolean selecting;
+
+	guint show_selection_idle_id;
 };
 
 typedef struct {
@@ -138,6 +140,8 @@ show_selection_idle_callback (gpointer callback_data)
 
 	view = NAUTILUS_TREE_VIEW (callback_data);
 
+	view->details->show_selection_idle_id = 0;
+
 	file = nautilus_file_get (view->details->selection_location);
 	if (file == NULL) {
 		return FALSE;
@@ -172,6 +176,14 @@ show_selection_idle_callback (gpointer callback_data)
 	return FALSE;
 }
 
+static void
+schedule_show_selection (NautilusTreeView *view)
+{
+	if (view->details->show_selection_idle_id == 0) {
+		view->details->show_selection_idle_id = g_idle_add (show_selection_idle_callback, view);
+	}
+}
+
 static void
 row_loaded_callback (GtkTreeModel     *tree_model,
 		     GtkTreeIter      *iter,
@@ -201,7 +213,7 @@ row_loaded_callback (GtkTreeModel     *tree_model,
 			nautilus_file_unref (file);
 			nautilus_file_unref (selection_file);
 
-			g_idle_add (show_selection_idle_callback, view);
+			schedule_show_selection (view);
 			return;
 		}
 		tmp_file = nautilus_file_get_parent (selection_file);
@@ -269,7 +281,12 @@ got_activation_uri_callback (NautilusFile *file, gpointer callback_data)
 
 		/* Non-local executables don't get launched. They act like non-executables. */
 		if (file_uri == NULL) {
-			nautilus_view_open_location_in_this_window (NAUTILUS_VIEW (view), uri);
+			nautilus_view_open_location
+				(NAUTILUS_VIEW (view), 
+				 uri, 
+				 Nautilus_ViewFrame_OPEN_ACCORDING_TO_MODE,
+				 0,
+				 NULL);
 		} else {
 			nautilus_launch_application_from_command (screen, NULL, file_uri, NULL, FALSE);
 			g_free (file_uri);
@@ -282,7 +299,12 @@ got_activation_uri_callback (NautilusFile *file, gpointer callback_data)
 				g_free (view->details->selection_location);
 			}
 			view->details->selection_location = g_strdup (uri);
-			nautilus_view_open_location_in_this_window (NAUTILUS_VIEW (view), uri);
+			nautilus_view_open_location
+				(NAUTILUS_VIEW (view), 
+				 uri,
+				 Nautilus_ViewFrame_OPEN_ACCORDING_TO_MODE,
+				 0,
+				 NULL);
 		}
 	}
 
@@ -305,6 +327,19 @@ cancel_activation (NautilusTreeView *view)
         view->details->activation_file = NULL;
 }
 
+static void
+row_activated_callback (GtkTreeView *treeview, GtkTreePath *path, 
+			GtkTreeViewColumn *column, NautilusTreeView *view)
+{
+	if (gtk_tree_view_row_expanded (view->details->tree_widget, path)) {
+		gtk_tree_view_collapse_row (view->details->tree_widget, path);
+	} else {
+		gtk_tree_view_expand_row (view->details->tree_widget, 
+					  path, FALSE);
+	}
+}
+
+
 static void
 selection_changed_callback (GtkTreeSelection *selection,
 			    NautilusTreeView *view)
@@ -312,7 +347,7 @@ selection_changed_callback (GtkTreeSelection *selection,
 	NautilusFileAttributes attributes;
 	GtkTreeIter iter;
 
-        cancel_activation (view);
+	cancel_activation (view);
 
 	if (!gtk_tree_selection_get_selected (selection, NULL, &iter)) {
 		return;
@@ -420,29 +455,25 @@ theme_changed_callback (GObject *icon_factory, gpointer callback_data)
 {
         NautilusTreeView *view; 
 
-        view = NAUTILUS_TREE_VIEW (callback_data); 
-        nautilus_tree_model_set_theme (NAUTILUS_TREE_MODEL (view->details->child_model));  
+        view = NAUTILUS_TREE_VIEW (callback_data);
+	if (view->details->child_model != NULL) {
+		nautilus_tree_model_set_theme (NAUTILUS_TREE_MODEL (view->details->child_model));
+	}
 }
 
 static void
 add_root_for_volume (NautilusTreeView *view,
-		     const NautilusVolume *volume)
+		     GnomeVFSVolume *volume)
 {
 	char *icon, *mount_uri, *name;
 
-	if (nautilus_volume_is_in_removable_blacklist (volume)) {
-		return;
-	}
-
-	if (!nautilus_volume_is_removable (volume)) {
+	if (!gnome_vfs_volume_is_user_visible (volume)) {
 		return;
 	}
 	
-	/* Name uniqueness is handled by nautilus-desktop-link-monitor.c... */
-	
-	icon = nautilus_volume_get_icon (volume);
-	mount_uri = nautilus_volume_get_target_uri (volume);
-	name = nautilus_volume_get_name (volume);
+	icon = gnome_vfs_volume_get_icon (volume);
+	mount_uri = gnome_vfs_volume_get_activation_uri (volume);
+	name = gnome_vfs_volume_get_display_name (volume);
 	
 	nautilus_tree_model_add_root_uri (view->details->child_model,
 					  mount_uri, name, icon);
@@ -454,29 +485,21 @@ add_root_for_volume (NautilusTreeView *view,
 }
 
 static void
-volume_mounted_callback (NautilusVolumeMonitor *volume_monitor,
-			 NautilusVolume *volume,
+volume_mounted_callback (GnomeVFSVolumeMonitor *volume_monitor,
+			 GnomeVFSVolume *volume,
 			 NautilusTreeView *view)
 {
 	add_root_for_volume (view, volume);
 }
 
-static gboolean
-add_one_volume_root (const NautilusVolume *volume, gpointer callback_data)
-{
-	add_root_for_volume (NAUTILUS_TREE_VIEW (callback_data), volume);
-
-	return TRUE;
-}
-
 static void
-volume_unmounted_callback (NautilusVolumeMonitor *volume_monitor,
-			   NautilusVolume *volume,
+volume_unmounted_callback (GnomeVFSVolumeMonitor *volume_monitor,
+			   GnomeVFSVolume *volume,
 			   NautilusTreeView *view)
 {
 	char *mount_uri;
 	
-	mount_uri = nautilus_volume_get_target_uri (volume);
+	mount_uri = gnome_vfs_volume_get_activation_uri (volume);
 	nautilus_tree_model_remove_root_uri (view->details->child_model,
 					     mount_uri);
 	g_free (mount_uri);
@@ -488,8 +511,9 @@ create_tree (NautilusTreeView *view)
 {
 	GtkCellRenderer *cell;
 	GtkTreeViewColumn *column;
-	NautilusVolumeMonitor *volume_monitor;
+	GnomeVFSVolumeMonitor *volume_monitor;
 	char *home_uri;
+	GList *volumes, *l;
 	
 	view->details->child_model = nautilus_tree_model_new ();
 	view->details->sort_model = GTK_TREE_MODEL_SORT
@@ -509,10 +533,13 @@ create_tree (NautilusTreeView *view)
 	nautilus_tree_model_add_root_uri (view->details->child_model, "network:///", _("Network Neighbourhood"), "gnome-fs-network");
 #endif
 	
-	volume_monitor = nautilus_volume_monitor_get ();
-	nautilus_volume_monitor_each_mounted_volume (volume_monitor,
-					     	     add_one_volume_root,
-						     view);
+	volume_monitor = gnome_vfs_get_volume_monitor ();
+	volumes = gnome_vfs_volume_monitor_get_mounted_volumes (volume_monitor);
+	for (l = volumes; l != NULL; l = l->next) {
+		add_root_for_volume (view, l->data);
+		gnome_vfs_volume_unref (l->data);
+	}
+	g_list_free (volumes);
 	
 	g_signal_connect_object (volume_monitor, "volume_mounted",
 				 G_CALLBACK (volume_mounted_callback), view, 0);
@@ -570,7 +597,11 @@ create_tree (NautilusTreeView *view)
 	g_signal_connect_object (gtk_tree_view_get_selection (GTK_TREE_VIEW (view->details->tree_widget)), "changed",
 				 G_CALLBACK (selection_changed_callback), view, 0);
 
-	g_idle_add (show_selection_idle_callback, view);
+	g_signal_connect (G_OBJECT (view->details->tree_widget), 
+			  "row-activated", G_CALLBACK (row_activated_callback),
+			  view);
+
+	schedule_show_selection (view);
 }
 
 static void
@@ -618,7 +649,7 @@ load_location_callback (NautilusTreeView *view, char *location)
 	}
 	view->details->selection_location = g_strdup (location);
 
-	g_idle_add (show_selection_idle_callback, view);
+	schedule_show_selection (view);
 }
 
 static void
@@ -670,6 +701,13 @@ nautilus_tree_view_dispose (GObject *object)
 		g_object_unref (view->details->drag_dest);
 		view->details->drag_dest = NULL;
 	}
+
+	if (view->details->show_selection_idle_id) {
+		g_source_remove (view->details->show_selection_idle_id);
+		view->details->show_selection_idle_id = 0;
+	}
+
+	G_OBJECT_CLASS (parent_class)->dispose (object);
 }
 
 static void
