@@ -53,7 +53,7 @@ struct NautilusDesktopLinkDetails {
 	gulong trash_state_handler;
 
 	/* Just for volume icons: */
-	char *mount_path;
+	GnomeVFSVolume *volume;
 };
 
 static void nautilus_desktop_link_init       (gpointer              object,
@@ -89,6 +89,20 @@ home_name_changed (gpointer callback_data)
 	nautilus_desktop_link_changed (link);
 }
 
+static void
+computer_name_changed (gpointer callback_data)
+{
+	NautilusDesktopLink *link;
+
+	link = NAUTILUS_DESKTOP_LINK (callback_data);
+	g_assert (link->details->type == NAUTILUS_DESKTOP_LINK_COMPUTER);
+
+	g_free (link->details->display_name);
+	link->details->display_name = eel_preferences_get (NAUTILUS_PREFERENCES_DESKTOP_COMPUTER_NAME);
+	
+	nautilus_desktop_link_changed (link);
+}
+
 static void
 trash_name_changed (gpointer callback_data)
 {
@@ -134,6 +148,22 @@ nautilus_desktop_link_new (NautilusDesktopLinkType type)
 					      link);
 		
 		break;
+		
+	case NAUTILUS_DESKTOP_LINK_COMPUTER:
+		link->details->filename = g_strdup ("computer");
+
+		link->details->display_name = eel_preferences_get (NAUTILUS_PREFERENCES_DESKTOP_COMPUTER_NAME);
+		
+		link->details->activation_uri = g_strdup ("computer:///");
+		/* TODO: This might need a different icon: */
+		link->details->icon = g_strdup ("gnome-fs-client");
+
+		eel_preferences_add_callback (NAUTILUS_PREFERENCES_DESKTOP_COMPUTER_NAME,
+					      computer_name_changed,
+					      link);
+		
+		break;
+		
 	case NAUTILUS_DESKTOP_LINK_TRASH:
 		link->details->filename = g_strdup ("trash");
 		link->details->display_name = g_strdup (_("Trash"));
@@ -162,49 +192,45 @@ nautilus_desktop_link_new (NautilusDesktopLinkType type)
 }
 
 NautilusDesktopLink *
-nautilus_desktop_link_new_from_volume (const NautilusVolume *volume)
+nautilus_desktop_link_new_from_volume (GnomeVFSVolume *volume)
 {
 	NautilusDesktopLink *link;
-	const char *mount_path;
-	char *underscore_mount_path, *p;
+	GnomeVFSDrive *drive;
+	char *name;
 
 	link = NAUTILUS_DESKTOP_LINK (g_object_new (NAUTILUS_TYPE_DESKTOP_LINK, NULL));
 	
 	link->details->type = NAUTILUS_DESKTOP_LINK_VOLUME;
 
-	mount_path = nautilus_volume_get_mount_path (volume);
-	link->details->mount_path = g_strdup (mount_path);
-	
-	/* Convert slashes in the mount path to underscores and skip
-	   first slash */
-	while (*mount_path == '/') {
-		mount_path ++;
-	}
-	underscore_mount_path = g_strdup (mount_path);
-	for (p = underscore_mount_path; *p != 0; p++) {
-		if (*p == '/') {
-			*p = '_';
-		}
-	}
+	link->details->volume = gnome_vfs_volume_ref (volume);
 
-	link->details->filename = g_strconcat ("mount_", underscore_mount_path, NULL);
-	g_free (underscore_mount_path);
+	/* We try to use the drive name to get somewhat stable filenames
+	   for metadata */
+	drive = gnome_vfs_volume_get_drive (volume);
+	if (drive != NULL) {
+		name = gnome_vfs_drive_get_display_name (drive);
+	} else {
+		name = gnome_vfs_volume_get_display_name (volume);
+	}
+	gnome_vfs_drive_unref (drive);
 	
-	link->details->display_name = nautilus_volume_get_name (volume);
+	link->details->filename = g_strconcat (name, ".volume", NULL);
+	g_free (name);
 	
-	link->details->activation_uri = nautilus_volume_get_target_uri (volume);
-	link->details->icon = nautilus_volume_get_icon (volume);
+	link->details->display_name = gnome_vfs_volume_get_display_name (volume);
+	
+	link->details->activation_uri = gnome_vfs_volume_get_activation_uri (volume);
+	link->details->icon = gnome_vfs_volume_get_icon (volume);
 	
 	create_icon_file (link);
 
 	return link;
 }
 
-char *
-nautilus_desktop_link_get_mount_path (NautilusDesktopLink *link)
+GnomeVFSVolume *
+nautilus_desktop_link_get_volume (NautilusDesktopLink *link)
 {
-	g_assert (link->details->type == NAUTILUS_DESKTOP_LINK_VOLUME);
-	return g_strdup (link->details->mount_path);
+	return gnome_vfs_volume_ref (link->details->volume);
 }
 
 
@@ -309,6 +335,10 @@ nautilus_desktop_link_rename (NautilusDesktopLink     *link,
 		eel_preferences_set (NAUTILUS_PREFERENCES_DESKTOP_HOME_NAME,
 				     name);
 		break;
+	case NAUTILUS_DESKTOP_LINK_COMPUTER:
+		eel_preferences_set (NAUTILUS_PREFERENCES_DESKTOP_COMPUTER_NAME,
+				     name);
+		break;
 	case NAUTILUS_DESKTOP_LINK_TRASH:
 		eel_preferences_set (NAUTILUS_PREFERENCES_DESKTOP_TRASH_NAME,
 				     name);
@@ -361,12 +391,26 @@ desktop_link_finalize (GObject *object)
 						 link);
 	}
 	
+	if (link->details->type == NAUTILUS_DESKTOP_LINK_COMPUTER) {
+		eel_preferences_remove_callback (NAUTILUS_PREFERENCES_DESKTOP_COMPUTER_NAME,
+						 computer_name_changed,
+						 link);
+	}
+	
 	if (link->details->type == NAUTILUS_DESKTOP_LINK_TRASH) {
 		eel_preferences_remove_callback (NAUTILUS_PREFERENCES_DESKTOP_TRASH_NAME,
 						 trash_name_changed,
 						 link);
 	}
 	
+	if (link->details->type == NAUTILUS_DESKTOP_LINK_VOLUME) {
+		gnome_vfs_volume_unref (link->details->volume);
+	}
+
+	g_free (link->details->filename);
+	g_free (link->details->display_name);
+	g_free (link->details->activation_uri);
+	g_free (link->details->icon);
 	g_free (link->details);
 
 	EEL_CALL_PARENT (G_OBJECT_CLASS, finalize, (object));
