@@ -189,7 +189,7 @@ help_cb (GtkWidget *button, NautilusProgramChooser *program_chooser)
 		err_dialog = gtk_message_dialog_new (GTK_WINDOW (program_chooser),
 						     GTK_DIALOG_MODAL,
 						     GTK_MESSAGE_ERROR,
-						     GTK_BUTTONS_CLOSE,
+						     GTK_BUTTONS_OK,
 						     _("There was an error displaying help: %s"),
 						     error->message);
 
@@ -982,17 +982,6 @@ launch_mime_capplet (NautilusFile *file,
 	g_free (mime_type);
 }
 
-static void
-launch_mime_capplet_on_ok (GtkDialog *dialog, int response, gpointer callback_data)
-{
-	g_assert (GTK_IS_DIALOG (dialog));
-
-	if (response == GTK_RESPONSE_YES) {
-		launch_mime_capplet (callback_data, dialog);
-	}
-	gtk_object_destroy (GTK_OBJECT (dialog));
-}
-
 static void
 launch_mime_capplet_and_close_dialog (GtkButton *button, gpointer callback_data)
 {
@@ -1405,6 +1394,7 @@ nautilus_program_chooser_instance_init (NautilusProgramChooser *program_chooser)
 	/* Create and setup tree view */
 	create_and_set_up_tree_view (program_chooser);
 	gtk_container_add (GTK_CONTAINER (scrolled_window), program_chooser->details->tree_view);
+	gtk_label_set_mnemonic_widget (GTK_LABEL (program_chooser->details->prompt_label), program_chooser->details->tree_view);
 
 	/* Framed area with selection-specific details */
 	program_chooser->details->frame = gtk_frame_new (NULL);
@@ -1426,6 +1416,7 @@ nautilus_program_chooser_instance_init (NautilusProgramChooser *program_chooser)
   	gtk_box_pack_end (GTK_BOX (framed_hbox), change_button_holder, FALSE, FALSE, 0);
 
   	change_button = gtk_button_new_with_mnemonic (_("_Modify..."));
+	gtk_label_set_mnemonic_widget (GTK_LABEL (program_chooser->details->status_label), change_button);
 
 	g_signal_connect_object (change_button, "clicked",
 				 G_CALLBACK (run_program_configurator_callback), program_chooser, 0);
@@ -1455,6 +1446,7 @@ nautilus_program_chooser_instance_init (NautilusProgramChooser *program_chooser)
 
 	caption = gtk_label_new (_("You can configure which programs are offered "
 				   "for which file types in the File Types and Programs dialog."));
+	gtk_label_set_mnemonic_widget (GTK_LABEL (caption), capplet_button);
 	gtk_widget_show (caption);
 	gtk_label_set_line_wrap (GTK_LABEL (caption), TRUE);
 	gtk_box_pack_start (GTK_BOX (capplet_hbox), caption, FALSE, FALSE, 0);				    
@@ -1591,6 +1583,7 @@ nautilus_program_chooser_show_no_choices_message (GnomeVFSMimeActionType action_
 	char *file_name;
 	char *dialog_title;
 	GtkDialog *dialog;
+	int response;
 
 	file_name = get_file_name_for_display (file);
 
@@ -1609,22 +1602,22 @@ nautilus_program_chooser_show_no_choices_message (GnomeVFSMimeActionType action_
 	 * user can't add components to the complete list even from the capplet.
 	 * (They can add applications though.)
 	 */
-	prompt = g_strdup_printf (_("%s\n\n"
-				    "You can configure GNOME to associate applications "
-				    "with file types. Do you want to associate an "
-				    "application with this file type now?"),
-				  unavailable_message);
-	
-	dialog = eel_show_yes_no_dialog 
-		(prompt, dialog_title, _("Associate Application"), GTK_STOCK_CANCEL, parent_window);
+	prompt = _("You can configure GNOME to associate applications "
+		   "with file types. Do you want to associate an "
+		   "application with this file type now?");
+
+	dialog = eel_show_yes_no_dialog (unavailable_message, prompt, dialog_title, 
+	                                 _("_Associate Application"), GTK_STOCK_CANCEL, parent_window);
+
+	response = gtk_dialog_run (dialog);
+	gtk_object_destroy (GTK_OBJECT (dialog));
 		
-	g_signal_connect_object (dialog, "response",
-				 G_CALLBACK (launch_mime_capplet_on_ok),
-				 file, 0);
+	if (response == GTK_RESPONSE_YES) {
+		launch_mime_capplet (file, dialog);	 
+	}
 
 	g_free (unavailable_message);
 	g_free (file_name);
-	g_free (prompt);
 	g_free (dialog_title);
 }
 
@@ -1638,6 +1631,7 @@ nautilus_program_chooser_show_invalid_message (GnomeVFSMimeActionType  action_ty
 	char *file_name;
 	char *dialog_title;
 	GtkDialog *dialog;
+	int response;
 
 	file_name = get_file_name_for_display (file);
 
@@ -1652,21 +1646,21 @@ nautilus_program_chooser_show_invalid_message (GnomeVFSMimeActionType  action_ty
 		dialog_title = g_strdup (_("Invalid Action Associated"));
 	}		
 
-	prompt = g_strdup_printf (_("%s\n\n"
-				    "You can configure GNOME to associate a different application "
-				    "or viewer with this file type. Do you want to associate an "
-				    "application or viewer with this file type now?"),
-				  unavailable_message);
+	prompt = _("You can configure GNOME to associate a different application "
+		   "or viewer with this file type. Do you want to associate an "
+		   "application or viewer with this file type now?");
 
-	dialog = eel_show_yes_no_dialog 
-		(prompt, dialog_title, _("Associate Action"), GTK_STOCK_CANCEL, parent_window);
+	dialog = eel_show_yes_no_dialog (unavailable_message, prompt, dialog_title, 
+	                                 _("_Associate Action"), GTK_STOCK_CANCEL, parent_window);
 	
-	g_signal_connect_object (dialog, "response",
-	G_CALLBACK (launch_mime_capplet_on_ok),
-	file, 0);
+	response = gtk_dialog_run (dialog);
+	gtk_object_destroy (GTK_OBJECT (dialog));
+		
+	if (response == GTK_RESPONSE_YES) {
+		launch_mime_capplet (file, dialog);	 
+	}
 
 	g_free (unavailable_message);
 	g_free (file_name);
-	g_free (prompt);
 	g_free (dialog_title);
 }
