@@ -1771,8 +1771,9 @@ play_file (gpointer callback_data)
 	file_uri = nautilus_file_get_uri (file);
 	mime_type = nautilus_file_get_mime_type (file);
 	is_mp3 = eel_strcasecmp (mime_type, "audio/mpeg") == 0;
-	is_ogg = eel_strcasecmp (mime_type, "application/x-ogg") == 0;
-
+	is_ogg = eel_strcasecmp (mime_type, "application/x-ogg") == 0 ||
+                eel_strcasecmp (mime_type, "application/ogg") == 0;
+	
 	mp3_pid = fork ();
 	if (mp3_pid == (pid_t) 0) {
 		/* Set the group (session) id to this process for future killing. */
@@ -2541,8 +2542,9 @@ icon_view_handle_uri_list (NautilusIconContainer *container, const char *item_ur
 
 	if (eel_vfs_has_capability (container_uri,
 				    EEL_VFS_CAPABILITY_IS_REMOTE_AND_SLOW)) {
-		eel_show_warning_dialog (_("Drag and drop is only supported to local file systems."),
-					 _("Drag and Drop error"),
+		eel_show_warning_dialog (_("Drag and drop is not supported."),
+					 _("Drag and drop is only supported on local file systems."),
+					 _("Drag and Drop Error"),
 					 fm_directory_view_get_containing_window (FM_DIRECTORY_VIEW (view)));
 		g_free (container_uri);
 		return;
@@ -2564,8 +2566,9 @@ icon_view_handle_uri_list (NautilusIconContainer *container, const char *item_ur
 	    (action != GDK_ACTION_COPY) &&
 	    (action != GDK_ACTION_MOVE) &&
 	    (action != GDK_ACTION_LINK)) {
-		eel_show_warning_dialog (_("An invalid drag type was used."),
-					 _("Drag and Drop error"),
+		eel_show_warning_dialog (_("Drag and drop is not supported."),
+					 _("An invalid drag type was used."),
+					 _("Drag and Drop Error"),
 					 fm_directory_view_get_containing_window (FM_DIRECTORY_VIEW (view)));
 		g_free (container_uri);
 		return;
