@@ -911,7 +911,8 @@ remove_pattern(NautilusPropertyBrowser *property_browser, const char* pattern_na
 	/* delete the pattern from the pattern directory */
 	if (gnome_vfs_unlink (pattern_uri) != GNOME_VFS_OK) {
 		char *message = g_strdup_printf (_("Sorry, but pattern %s couldn't be deleted."), pattern_name);
-		eel_show_error_dialog (message, _("Couldn't delete pattern"), GTK_WINDOW (property_browser));
+		char *detail = _("Check that you have permission to delete the pattern.");
+		eel_show_error_dialog (message, detail, _("Couldn't Delete Pattern"), GTK_WINDOW (property_browser));
 		g_free (message);
 	}
 	
@@ -940,7 +941,8 @@ remove_emblem (NautilusPropertyBrowser *property_browser, const char* emblem_nam
 	/* delete the emblem from the emblem directory */
 	if (gnome_vfs_unlink (emblem_uri) != GNOME_VFS_OK) {
 		char *message = g_strdup_printf (_("Sorry, but emblem %s couldn't be deleted."), emblem_name);
-		eel_show_error_dialog (message, _("Couldn't delete pattern"), GTK_WINDOW (property_browser));
+		char *detail = _("Check that you have permission to delete the emblem.");
+		eel_show_error_dialog (message, detail, _("Couldn't Delete Emblem"), GTK_WINDOW (property_browser));
 		g_free (message);
 	}
 	else {
@@ -1097,12 +1099,15 @@ add_pattern_to_browser (const char *path_name, gpointer *data)
 	/* make sure that it's a valid path */
 	if (path_name == NULL || path_name[0] != '/') {
 		char *message;
+		char *detail;
 		if (path_name != NULL) {
 			message = g_strdup_printf (_("Sorry, but \"%s\" is not a valid file name."), path_name);
+			detail = _("Please check the spelling and try again.");
 		} else {
 			message = g_strdup (_("Sorry, but you did not supply a valid file name."));
+			detail = _("Please try again.");
 		}
-		eel_show_error_dialog (message, _("Couldn't install pattern"), GTK_WINDOW (property_browser));
+		eel_show_error_dialog (message, detail, _("Couldn't Install Pattern"), GTK_WINDOW (property_browser));
 		g_free (message);
 		return;
 	}
@@ -1113,7 +1118,9 @@ add_pattern_to_browser (const char *path_name, gpointer *data)
 	/* don't allow the user to change the reset image */
 	basename = eel_uri_get_basename (path_uri);
 	if (basename && eel_strcmp (basename, RESET_IMAGE_NAME) == 0) {
-		eel_show_error_dialog (_("Sorry, but you can't replace the reset image."), _("Not an Image"), NULL);
+		eel_show_error_dialog (_("Sorry, but you can't replace the reset image."), 
+		                       _("Reset is a special image that cannot be deleted."), 
+		                       _("Not an Image"), NULL);
 		g_free (path_uri);
 		g_free (basename);
 		return;
@@ -1145,7 +1152,7 @@ add_pattern_to_browser (const char *path_name, gpointer *data)
 	result = eel_copy_uri_simple (path_name, destination_name);		
 	if (result != GNOME_VFS_OK) {
 		char *message = g_strdup_printf (_("Sorry, but the pattern %s couldn't be installed."), path_name);
-		eel_show_error_dialog (message, _("Couldn't install pattern"), GTK_WINDOW (property_browser));
+		eel_show_error_dialog (message, NULL, _("Couldn't Install Pattern"), GTK_WINDOW (property_browser));
 		g_free (message);
 	}
 		
@@ -1225,8 +1232,9 @@ add_color_to_browser (GtkWidget *widget, gint which_button, gpointer *data)
 		color_name = gtk_entry_get_text (GTK_ENTRY (property_browser->details->color_name));
 		stripped_color_name = g_strstrip (g_strdup (color_name));
 		if (strlen (stripped_color_name) == 0) {
-			eel_show_error_dialog (_("Sorry, but you must specify a non-blank name for the new color."), 
-						    _("Couldn't install color"), GTK_WINDOW (property_browser));
+			eel_show_error_dialog (_("The color cannot be installed."),
+					       _("Sorry, but you must specify a non-blank name for the new color."), 
+			                       _("Couldn't Install Color"), GTK_WINDOW (property_browser));
 		
 		} else {
 			add_color_to_file (property_browser, color_spec, stripped_color_name);
@@ -1315,8 +1323,8 @@ emblem_dialog_clicked (GtkWidget *dialog, int which_button, NautilusPropertyBrow
 					property_browser->details->image_path = emblem_path;				
 				} else {
 					char *message = g_strdup_printf
-						(_("Sorry, but '%s' is not a usable image file!"), emblem_path);
-					eel_show_error_dialog (message, _("Not an Image"), GTK_WINDOW (property_browser));
+						(_("Sorry, but \"%s\" is not a usable image file."), emblem_path);
+					eel_show_error_dialog (_("The file is not an image."), message, _("Not an Image"), GTK_WINDOW (property_browser));
 					g_free (message);
 					g_free (emblem_path);
 					return;
@@ -1331,8 +1339,9 @@ emblem_dialog_clicked (GtkWidget *dialog, int which_button, NautilusPropertyBrow
 
 		if (pixbuf == NULL) {
 			char *message = g_strdup_printf
-				(_("Sorry, but '%s' is not a usable image file!"), property_browser->details->image_path);
-			eel_show_error_dialog (message, _("Not an Image"), GTK_WINDOW (property_browser));
+				(_("Sorry, but \"%s\" is not a usable image file."), property_browser->details->image_path);
+			eel_show_error_dialog (_("The file is not an image."), message, _("Not an Image"), GTK_WINDOW (property_browser));
+			g_free (message);
 		}
 		
 		new_keyword = gtk_entry_get_text(GTK_ENTRY(property_browser->details->keyword));		
